"""
A spin-off experiment may start from a day, where no event-generator restart file is available.
This script finds the last available restart file in the event-generator directory.
From this date, the event-generator member can be restarted.
"""
from glob import glob
from dateutil.parser import parse
from datetime import datetime, timedelta

DIR_MOTHER_RUN = '/scratch/p/Philip.Rupp/experiments/2chunks/20201001/m1'
SPIN_OFF_START = '2020-10-20'
NOT_MORE_THAN_N_DAYS_BACK = 30


def infer_restart_dates_from_files_in_direcory(directory):
    restart_files = glob(directory + '/*restart*.nc')

    inferred_restart_file_dates = [parse(f.split("atm")[-1], fuzzy=True, ignoretz=True) for f in restart_files]
    return inferred_restart_file_dates


def find_date_before(target_date, dates_list, max_lag=None):
    # Convert the target_date to a datetime object if it's not already
    if not isinstance(target_date, datetime):
        target_date = datetime.strptime(target_date, '%Y-%m-%d')  # Adjust the format if needed

    # Calculate the minimum date allowed (if NOT_MORE_THAN_N_DAYS is provided)
    if max_lag is not None:
        min_date_allowed = target_date - timedelta(days=max_lag)
    else:
        min_date_allowed = datetime.min  # If NOT_MORE_THAN_N_DAYS is not provided, set a very early date

    # Filter dates_list to get only the dates that occur before the target_date
    filtered_dates = [dt for dt in dates_list if min_date_allowed <= dt < target_date]

    # Find the maximum date from the filtered dates (i.e., the date that occurs first before the target_date)
    if filtered_dates:
        return max(filtered_dates)
    else:
        return None  # No date found before the target_date


if __name__ == "__main__":
    restart_file_dates = infer_restart_dates_from_files_in_direcory(DIR_MOTHER_RUN)
    restart_from = find_date_before(SPIN_OFF_START, restart_file_dates, max_lag=NOT_MORE_THAN_N_DAYS_BACK)
    print(restart_from)
